Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(205)

Unified Diff: Source/WebCore/rendering/RenderView.h

Issue 10913088: Revert 127609 - Merge 124969 (Closed) Base URL: http://svn.webkit.org/repository/webkit/branches/chromium/1229/
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/WebCore/rendering/RenderQuote.cpp ('k') | Source/WebCore/rendering/RenderView.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/WebCore/rendering/RenderView.h
===================================================================
--- Source/WebCore/rendering/RenderView.h (revision 127609)
+++ Source/WebCore/rendering/RenderView.h (working copy)
@@ -32,7 +32,6 @@
class FlowThreadController;
class RenderWidget;
-class RenderQuote;
#if USE(ACCELERATED_COMPOSITING)
class RenderLayerCompositor;
@@ -195,13 +194,13 @@
void setFixedPositionedObjectsNeedLayout();
- void setRenderQuoteHead(RenderQuote* head) { m_renderQuoteHead = head; }
- RenderQuote* renderQuoteHead() const { return m_renderQuoteHead; }
-
- // FIXME: This is a work around because the current implementation of counters
+ // FIXME: This is a work around because the current implementation of counters and quotes
// requires walking the entire tree repeatedly and most pages don't actually use either
// feature so we shouldn't take the performance hit when not needed. Long term we should
// rewrite the counter and quotes code.
+ void addRenderQuote() { m_renderQuoteCount++; }
+ void removeRenderQuote() { ASSERT(m_renderQuoteCount > 0); m_renderQuoteCount--; }
+ bool hasRenderQuotes() { return m_renderQuoteCount; }
void addRenderCounter() { m_renderCounterCount++; }
void removeRenderCounter() { ASSERT(m_renderCounterCount > 0); m_renderCounterCount--; }
bool hasRenderCounters() { return m_renderCounterCount; }
@@ -302,7 +301,7 @@
OwnPtr<FlowThreadController> m_flowThreadController;
RefPtr<IntervalArena> m_intervalArena;
- RenderQuote* m_renderQuoteHead;
+ unsigned m_renderQuoteCount;
unsigned m_renderCounterCount;
};
« no previous file with comments | « Source/WebCore/rendering/RenderQuote.cpp ('k') | Source/WebCore/rendering/RenderView.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698